pub struct DaemonClient { /* private fields */ }Implementations
Sourceimpl DaemonClient
impl DaemonClient
Sourcepub async fn connect(socket_path: &Path) -> Result<Self>
pub async fn connect(socket_path: &Path) -> Result<Self>
Connect to a running daemon at the given socket path.
Errors
Returns an error if the connection fails.
Sourcepub async fn connect_or_start(socket_path: &Path) -> Result<Self>
pub async fn connect_or_start(socket_path: &Path) -> Result<Self>
Connect to the daemon, auto-starting it if not running.
Errors
Returns an error if the daemon cannot be started or connected to.