pub fn run(opts: &SearchOptions, project_root: &Path) -> Result<SearchOutput>Expand description
Run the search and return aggregated results.
Errors
Returns an error if the regex pattern is invalid or file walking fails.
pub fn run(opts: &SearchOptions, project_root: &Path) -> Result<SearchOutput>Run the search and return aggregated results.
Returns an error if the regex pattern is invalid or file walking fails.