pub fn handle_clean(format: OutputFormat) -> Result<()>Expand description
Handle krait server clean.
Errors
Returns an error if the clean operation or JSON serialization fails.
pub fn handle_clean(format: OutputFormat) -> Result<()>Handle krait server clean.
Returns an error if the clean operation or JSON serialization fails.