detect_project_root

Function detect_project_root 

pub fn detect_project_root(from: &Path) -> PathBuf
Walk up from from to find the project root by looking for known markers. Returns the directory containing the first marker found, or from as fallback.