Skip to main contentModule builder
Source - FileEntry
- A file entry to be indexed: absolute path, relative path, and BLAKE3 hash.
- IndexStats
- Statistics from an index build.
- collect_symbols
- Query LSP for document symbols using pipelined batches with parallel disk I/O.
- collect_symbols_parallel
- Index files using N parallel LSP workers for a single language.
- commit_index
- Write collected symbols to the index store in a single transaction.
- detect_batch_size
- Detect optimal batch size for pipelined LSP requests based on system resources.
- detect_worker_count
- Detect the number of parallel init workers based on system resources.
- plan_index
- Determine which files need (re)indexing by comparing BLAKE3 hashes.