cached_read_symbol

Function cached_read_symbol 

pub fn cached_read_symbol(
    store: &IndexStore,
    name: &str,
    signature_only: bool,
    max_lines: Option<u32>,
    project_root: &Path,
    dirty_files: Option<&DirtyFiles>,
) -> Option<Value>
Serve read symbol from the cache. Returns None if symbol not found or file stale.

Supports dotted names (e.g., Config.new) by searching for the parent first, then finding the child in the same file’s symbols.