pub struct DirtyFiles { /* private fields */ }Expand description
Thread-safe set of file paths known to be dirty (changed since last index).
Implementations
Sourceimpl DirtyFiles
impl DirtyFiles
pub fn new() -> Self
Sourcepub fn mark_dirty(&self, rel_path: String)
pub fn mark_dirty(&self, rel_path: String)
Mark a relative path as dirty.
Sourcepub fn is_dirty(&self, rel_path: &str) -> bool
pub fn is_dirty(&self, rel_path: &str) -> bool
Check if a relative path is dirty.
Returns true if the file is known to have changed, or if the watcher
is poisoned (overflow occurred).
Sourcepub fn clear(&self)
pub fn clear(&self)
Clear all dirty entries and reset poison flag.
Called after re-indexing (krait init).
Sourcepub fn is_poisoned(&self) -> bool
pub fn is_poisoned(&self) -> bool
Whether the watcher is poisoned (overflow occurred).