pub async fn download_server(entry: &ServerEntry) -> Result<PathBuf>Expand description
Download and install an LSP server binary.
Errors
Returns an error if the download or installation fails.
pub async fn download_server(entry: &ServerEntry) -> Result<PathBuf>Download and install an LSP server binary.
Returns an error if the download or installation fails.