pub fn find_server(entry: &ServerEntry) -> Option<PathBuf>Expand description
Find the server binary for a specific entry — checks PATH first, then managed directory.
pub fn find_server(entry: &ServerEntry) -> Option<PathBuf>Find the server binary for a specific entry — checks PATH first, then managed directory.