Request

Enum Request 

pub enum Request {
Show 19 variants Status, DaemonStop, Init, Check { path: Option<PathBuf>, errors_only: bool, }, FindSymbol { name: String, path_filter: Option<String>, src_only: bool, include_body: bool, }, FindImpl { name: String, }, FindRefs { name: String, with_symbol: bool, }, ListSymbols { path: PathBuf, depth: u8, }, ReadFile { path: PathBuf, from: Option<u32>, to: Option<u32>, max_lines: Option<u32>, }, ReadSymbol { name: String, signature_only: bool, max_lines: Option<u32>, path_filter: Option<String>, has_body: bool, }, EditReplace { symbol: String, code: String, }, EditInsertAfter { symbol: String, code: String, }, EditInsertBefore { symbol: String, code: String, }, Hover { name: String, }, Format { path: PathBuf, }, Rename { name: String, new_name: String, }, Fix { path: Option<PathBuf>, }, ServerStatus, ServerRestart { language: String, },
}

Variants



Status



DaemonStop



Init



Check

Fields

errors_only: bool

If true, suppress warnings and hints.



FindSymbol

Fields

name: String
path_filter: Option<String>

Substring filter applied to result paths (for disambiguation)

src_only: bool

Exclude noise paths (www/, dist/, node_modules/, .d.ts, .mdx)

include_body: bool

Include full symbol body in each result



FindImpl

Fields

name: String


FindRefs

Fields

name: String
with_symbol: bool

Enrich each reference with its containing symbol



ListSymbols

Fields

path: PathBuf
depth: u8


ReadFile

Fields

path: PathBuf
from: Option<u32>
max_lines: Option<u32>


ReadSymbol

Fields

name: String
signature_only: bool
max_lines: Option<u32>
path_filter: Option<String>

Substring filter to select the right definition when multiple exist

has_body: bool

Skip overload stubs and return the real implementation body



EditReplace

Fields

symbol: String
code: String


EditInsertAfter

Fields

symbol: String
code: String


EditInsertBefore

Fields

symbol: String
code: String


Hover

Fields

name: String


Format

Fields

path: PathBuf


Rename

Fields

name: String
new_name: String


Fix

Fields



ServerStatus

Get running LSP server status from daemon



ServerRestart

Restart a language server in the daemon

Fields

language: String