pub fn commit_index(
store: &IndexStore,
results: &[(String, String, Vec<CachedSymbol>)],
) -> Result<usize>Expand description
Write collected symbols to the index store in a single transaction.
Errors
Returns an error if upserting files or inserting symbols into the store fails.