pub fn base_name(s: &str) -> &strExpand description
Strip Go method receiver prefix from a symbol name.
Go struct methods are indexed with a receiver prefix:
"(*ReceiverType).MethodName" or "ReceiverType.MethodName"
Returns the base name (everything after the last ")."), or the original
string if no receiver prefix is present.